summaryrefslogtreecommitdiffstats
path: root/karm/timekard.h
diff options
context:
space:
mode:
Diffstat (limited to 'karm/timekard.h')
-rw-r--r--karm/timekard.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/karm/timekard.h b/karm/timekard.h
index f47129fd..df0bd328 100644
--- a/karm/timekard.h
+++ b/karm/timekard.h
@@ -46,12 +46,12 @@ class TaskView;
class Week
{
public:
/** Need an empty constructor to use in a QValueList. */
Week();
- Week(QDate from);
- QDate start() const;
- QDate end() const;
- QValueList<QDate> days() const;
+ Week(TQDate from);
+ TQDate start() const;
+ TQDate end() const;
+ TQValueList<TQDate> days() const;
/**
* Returns a list of weeks for the given date range.
@@ -63,8 +63,8 @@ class Week
* days, one being a Sunday and the other being a Monday, you will get two
* weeks back in the list.
*/
- static QValueList<Week> weeksFromDateRange(const QDate& from,
- const QDate& to);
+ static TQValueList<Week> weeksFromDateRange(const TQDate& from,
+ const TQDate& to);
/**
* Return the name of the week.
@@ -72,11 +72,11 @@ class Week
* Uses whatever the user has set up for the long date format in
* KControlPanel, prefixed by "Week of".
*/
- QString name() const;
+ TQString name() const;
private:
- QDate _start;
+ TQDate _start;
};
/**
@@ -101,28 +101,28 @@ class TimeKard
* print the task subtree for a root task and when they want to print
* all tasks.
*/
- QString totalsAsText(TaskView* taskview, bool justThisTask, WhichTime which);
+ TQString totalsAsText(TaskView* taskview, bool justThisTask, WhichTime which);
/**
* Generates ascii text of weekly task history, for current task on down.
*
* Formatted for pasting into clipboard.
*/
- QString historyAsText(TaskView* taskview, const QDate& from,
- const QDate& to, bool justThisTask, bool perWeek, bool totalsOnly);
+ TQString historyAsText(TaskView* taskview, const TQDate& from,
+ const TQDate& to, bool justThisTask, bool perWeek, bool totalsOnly);
private:
- void printTask(Task *t, QString &s, int level, WhichTime which);
+ void printTask(Task *t, TQString &s, int level, WhichTime which);
- void printTaskHistory(const Task *t, const QMap<QString, long>& datamap,
- QMap<QString, long>& daytotals,
- const QDate& from, const QDate& to,
- const int level, QString& retval, bool totalsOnly);
+ void printTaskHistory(const Task *t, const TQMap<TQString, long>& datamap,
+ TQMap<TQString, long>& daytotals,
+ const TQDate& from, const TQDate& to,
+ const int level, TQString& retval, bool totalsOnly);
- QString sectionHistoryAsText(TaskView* taskview,
- const QDate& sectionFrom, const QDate& sectionTo,
- const QDate& from, const QDate& to,
- const QString& name,
+ TQString sectionHistoryAsText(TaskView* taskview,
+ const TQDate& sectionFrom, const TQDate& sectionTo,
+ const TQDate& from, const TQDate& to,
+ const TQString& name,
bool justThisTask, bool totalsOnly);
};
@@ -46,12 +46,12 @@ class TaskView;
{
public:
- /** Need an empty constructor to use in a QValueList. */
+ /** Need an empty constructor to use in a TQValueList. */
Week();